
**	
**	Oscar E. Urdaneta - 22-10-2014
**	
**	Funcion ObtienePeriodoActual(cIdNomina)
**	Devuelve la fecha inicial del periodo siguiente a procesar o una fecha vacia
**	si no se han establecido los periodos o si ya fueron todos procesados
**	Recibe como parametro el Id de la nomina que se desea consultar.

FUNCTION ObtienePeriodoActual(cIdNomina)

	**	
	**	Variables locales.
	LOCAL ldProximoPeriodo
	LOCAL lcSqlCommand
	
	ldProximoPeriodo = {}
	
	lcSqlCommand = ''

	**	
	**	Busca el proximo periodo a procesar.
	lcSqlCommand =;
		"select " +;
			"num_peri.* " +;
		"from " +;
			"num_peri " +;
		"where " +;
			"num_peri.id_nomina = '" + cIdNomina + "' and " +;
		    "num_peri.estatus = '1' " +;
		"order by " +;
			"num_peri.desde " +;
		"limit 1"
	
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "curNumPeri")
	
	SELECT curNumPeri
	GO TOP
	
	IF ! EOF() THEN
		ldProximoPeriodo = curNumPeri.desde
	ENDIF
	
	USE

	**	
	**	Devuelve la fecha del proximo periodo.
	RETURN ldProximoPeriodo

ENDFUNC

**	
**	Oscar E. Urdaneta - 27-10-2014
**	
**	Funcion Agrega2doBS(cRuta)
**	Agrega un segundo backslash a la ruta indicada, se utiliza para almacenar las
**	rutas en campos de MySQL ya que este los maneja como cadenas de caracteres en C,
**	es decir, en lugar de "c:\premium" debe ser "c:\\premium", recibe como parametro
**	la ruta a corregir y la retorna con las modificaciones ya realizadas, lista para
**	ser almacenada.

FUNCTION Agrega2doBS(cRuta)

	**	
	**	Variables locales.
	LOCAL lnI
	LOCAL lcAux, lcChar
	
	lnI = 0
	
	lcAux = ''
	lcChar = ''
	
	FOR lnI = 1 TO LEN(cRuta) STEP 1
		lcChar = SUBSTR(cRuta, lnI, 1)
		lcAux = lcAux + lcChar
		IF lcChar = '\' THEN
			lcAux = lcAux + lcChar
		ENDIF
	ENDFOR
	
	RETURN lcAux

ENDFUNC

**	
**	Oscar E. Urdaneta - 17-10-2014
**	Calcula el salario integral de un empleado para un ao y mes especifico

FUNCTION SINTEGRAL(lcCodTrab, ldDesde, ldHasta)

	**	Variables locales.
	LOCAL llFlag
	LOCAL lnSalarioIntegral, lnSalarioBase, lnDiasPeriodo, lnAos
	LOCAL lnDiasBonoVac, lnFraccionVacaciones, lnFraccionUtilidades
	LOCAL lcSqlCommand
	
	llFlag = .F.
	
	lnSalarioIntegral	 = 0
	lnSalarioBase 		 = 0
	lnDiasPeriodo 		 = 0
	lnAos 				 = 0
	lnDiasBonoVac 		 = 0
	lnFraccionVacaciones = 0
	lnFraccionUtilidades = 0
	
	lcSqlCommand = ""
	
	**	
	**	Valida los parametros.
	**	En teoria esta condicion nunca deberia de cumplirse, se coloca a modo de depuracion.
	IF VARTYPE(lcCodTrab) != "C" THEN
		IF VARTYPE(nCod_Trab) = "C" AND ! EMPTY(nCod_Trab) THEN
			lcCodTrab = nCod_Trab
		ELSE
			= MESSAGEBOX("Se requiere del codigo del trabajador para el clculo del salario integral", 64, Software)
			RETURN lnSalarioIntegral
		ENDIF
	ENDIF
	
	IF VARTYPE(ldDesde) != "D" THEN
		IF VARTYPE(nDesde) = "D" AND ! EMPTY(nDesde) THEN
			ldDesde = nDesde
		ELSE
			= MESSAGEBOX("Se requiere la fecha inicial del periodo para el clculo del salario integral", 64, Software)
			RETURN lnSalarioIntegral
		ENDIF
	ENDIF

	IF VARTYPE(ldHasta) != "D" THEN
		IF VARTYPE(nHasta) = "D" AND ! EMPTY(nHasta) THEN
			ldHasta = nHasta
		ELSE
			= MESSAGEBOX("Se requiere la fecha final del periodo para el clculo del salario integral", 64, Software)
			RETURN lnSalarioIntegral
		ENDIF
	ENDIF

	**	
	**	Calcula los dias del periodo a procesar.
	lnDiasPeriodo = ldHasta - ldDesde + 1

	**	
	**	Busca el registro del empleado, fecha de ingreso y su sueldo actual.
	lcSqlCommand =;
		"select " +;
			"trabajad.cod_trab, " +;
			"trabajad.fecha_ing, " +;
			"consasig.valor " +;
		"from " +;
			"trabajad " +;
			"left join " +;
				"consasig " +;
			"on " +;
				"consasig.cod_trab = '" + lcCodTrab + "' and " +;
				"consasig.cod_const = 'SUEL' " +;
		"where " +;
			"trabajad.cod_trab = '" + lcCodTrab + "'"
	
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "curTrabajador")
	
	**	
	**	Corrige valores nulos.
	SELECT;
		curTrabajador.cod_trab,;
		curTrabajador.fecha_ing,;
		IIF(ISNULL(curTrabajador.Valor), 0, curTrabajador.Valor) AS Valor;
	FROM;
		curTrabajador;
	INTO CURSOR;
		curTrabajador;
	READWRITE
	
	**	
	**	Valida que el ao/mes a consultar sea igual o posterior a la fecha de ingreso del trabajador.
	IF curTrabajador.fecha_ing > ldDesde THEN
		= MESSAGEBOX("La fecha de ingreso del trabajador (" + ALLTRIM(lcCodTrab) + ") " + DTOC(curTrabajador.fecha_ing) + " " +;
		"es posterior al periodo a procesar (" + DTOC(ldDesde) + ")", 64, Software)
		RETURN lnSalarioIntegral
	ENDIF
	
	**	
	**	Busca el salario base (diario) para el periodo indicado.
	lcSqlCommand =;
		"select " +;
			"nominas2.* " +;
		"from " +;
			"nominas2 " +;
		"where " +;
			"nominas2.cod_trab = '" + lcCodTrab + "' and " +;
			"nominas2.desde = '" + date2mysql(ldDesde) + "' and " +;
			"nominas2.hasta = '" + date2mysql(ldHasta) + "' and " +;
			"(nominas2.cod_concep = '1001' or nominas2.cod_concep = '1002')"
	
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "curTempNominas2")
	
	SELECT curTempNominas2
	GO TOP
	
	IF EOF() THEN
		lnSalarioBase = ROUND(curTrabajador.valor / 30, 2)
	ELSE
		DO CASE
			CASE curTempNominas2.Cod_Concep = '1001'
				lnSalarioBase = ROUND(curTempNominas2.valor / 30, 2)
			CASE curTempNominas2.Cod_Concep = '1002'
				lnSalarioBase = ROUND(curTempNominas2.valor / 15, 2)
		ENDCASE
	ENDIF
	
	**	
	**	Calcula la antiguedad del trabajor, slo interesan los aos completos.
	lnAos = VAL(LEFT(calcula_antiguedad(curTrabajador.fecha_ing, ldDesde, .T.), 2))
	
	**	
	**	Elimina el primer ao.
	IF lnAos > 0 THEN
		lnAos = lnAos - 1
	ENDIF
	
	**	
	**	Busca los dias totales de bono vacacional para ese periodo.
	lcSqlCommand =;
		"select " +;
			"conf_vacaciones.* " +;
		"from " +;
			"conf_vacaciones " +;
		"order by " +;
			"conf_vacaciones.desde desc"

	ExeSentencia(OdbcMasterConector, lcSqlCommand, "curConf_Vacaciones")
	
	**	
	**	Determina cual ley aplica.
	SELECT curConf_Vacaciones
	GO TOP
	
	DO WHILE ! EOF()
		IF ldDesde >= curConf_Vacaciones.desde THEN
			llFlag = .T.
			EXIT
		ENDIF
		SKIP 1
	ENDDO
	
	IF ! llFlag THEN
		= MESSAGEBOX("No existe una ley de trabajo configurada para el periodo " + DTOC(ldDesde), 64, Software)
		RETURN lnSalarioIntegral
	ENDIF
	
	lnDiasBonoVac = curConf_Vacaciones.dias_bono + (curConf_Vacaciones.dias_mas * lnAos)
	
	IF lnDiasBonoVac > curConf_Vacaciones.max_dias THEN
		lnDiasBonoVac = curConf_Vacaciones.max_dias
	ENDIF
	
	**	
	**	Calcula la fraccion de vacaciones.
	lnFraccionVacaciones = ROUND(((lnDiasBonoVac / 12) / 30) * lnSalarioBase, 2)
	
	**	
	**	Busca los dias de utilidades para el periodo.
	lcSqlCommand =;
		"select " +;
			"confpres.* " +;
		"from " +;
			"confpres " +;
		"order by " +;
			"confpres.desde desc"
	
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "curConfPres")
	
	**	
	**	Determina que ley aplica.
	llFlag = .F.
	
	SELECT curConfPres
	GO TOP
	
	DO WHILE ! EOF()
		IF ldDesde >= curConfPres.desde THEN
			llFlag = .T.
			EXIT
		ENDIF
		SKIP 1
	ENDDO
	
	IF ! llFlag THEN
		= MESSAGEBOX("No existe una ley de trabajo configurada para el periodo " + DTOC(ldDesde), 64, Software)
		RETURN lnSalarioIntegral
	ENDIF
	
	**	Calcula la fraccion de utilidades.
	lnFraccionUtilidades = ROUND(((curConfPres.diasutil / 12) / 30) * lnSalarioBase, 2)
	
	**	Calcula el salario integral diario.
	lnSalarioIntegral 	 = ROUND((lnSalarioBase + lnFraccionVacaciones + lnFraccionUtilidades) * 30, 2)
	
	**	Destruye los cursores temporales.
	Borra_Cursor( "curTempNominas2" )
	Borra_Cursor( "curTrabajador") 
	Borra_Cursor( "curConf_Vacaciones")
	Borra_Cursor( "curConfPres")
	
	**	
	**	Retorna el valor.
	RETURN lnSalarioIntegral
	
ENDFUNC

**	
**	Calcula Adelantos de Prestaciones.
FUNCTION CalculaAdelantos(lcCodTrab, lcPeriodo)

	**	
	**	Variables locales.
	LOCAL lnAdelanto, lnAdelInte
	LOCAL lcAlias, lcSqlCommand
	
	lnAdelanto = 0
	lnAdelInte = 0
	
	lcAlias = ALIAS()
	lcSqlCommand = ''

	**	
	**	Si el periodo no es una cadena de caracteres o no tiene el ancho indicado (7 caracteres) lo
	**	convierte en una cadena vacia y asume que debe traer todos los adelantos del trabajador.
*!*		IF UPPER(VARTYPE(lcPeriodo)) != "C" THEN
*!*			lcPeriodo = ""
*!*		ELSE
*!*			IF LEN(lcPeriodo) != 7 THEN		&& Formato: 'MM-YYYY'
*!*				lcPeriodo = ""
*!*			ENDIF
*!*		ENDIF

	**	
	**	Construye el comando Sql.
	
	lcSqlCommand =;
		"select " +;
			"adelpres.* " +;
		"from " +;
			"adelpres " +;
		"where " +;
			"adelpres.id_nomina = '" + xId_Nomina + "' and " +;
			"adelpres.cod_trab = '" + ALLTRIM(lcCodtrab) + "'"
	
	IF ! EMPTY(lcPeriodo) THEN
		lcSqlCommand =;
			lcSqlCommand + " and " +;
			"adelpres.mescalc = '" + ALLTRIM(left(lcPeriodo, 2)) + "' and " +;
			"adelpres.annocalc = '" + ALLTRIM(RIGHT(ALLTRIM(lcPeriodo), 4)) + "'"
	ENDIF

	ExeSentencia(OdbcMasterConector, lcSqlCommand, "adelpres")
	
	SELECT adelpres
	GO TOP
	
	DO WHILE ! EOF() THEN
		lnAdelanto = lnAdelanto + adelpres.totadpres
		SKIP 1
	ENDDO
	
	USE
	
	**	
	**	Restaura el alias.
	IF ! EMPTY(lcAlias) AND USED(lcAlias) THEN
		SELECT &lcAlias
	ENDIF

	RETURN lnAdelanto

ENDFUNC

**	
**	Calcula el monto de los intereses pagados.
FUNCTION CalculaInteresesPagados(lcCodTrab, lcPeriodo)

	**	
	**	Variables locales.
	LOCAL lnIntPag
	LOCAL lcAlias, lcSqlCommand
	
	lnIntPag = 0
	
	lcAlias = ALIAS()
	lcSqlCommand = ''

	**	
	**	Si el periodo no es una cadena de caracteres o no tiene el ancho indicado (7 caracteres) lo
	**	convierte en una cadena vacia y asume que debe traer todos los intereses pagados del trabajador.
*!*		IF UPPER(VARTYPE(lcPeriodo)) != "C" THEN
*!*			lcPeriodo = ""
*!*		ELSE
*!*			IF LEN(lcPeriodo) != 7 THEN		&& Formato: 'MM-YYYY'
*!*				lcPeriodo = ""
*!*			ENDIF
*!*		ENDIF

	**	
	**	Construye el criterio de busqueda.
	lcSqlCommand =;
		"select " +;
			"adelinte.* " +;
		"from " +;
			"adelinte " +;
		"where " +;
			"adelinte.id_nomina = '" + xId_Nomina + "' and "	+;
			"adelinte.cod_trab = '" + ALLTRIM(lcCodTrab) + "'"
	
	IF ! EMPTY(lcPeriodo) THEN
		lcSqlCommand =;
			lcSqlCommand + " and " +;
			"month(adelinte.fec_adelan) = '" + ALLTRIM(left(lcPeriodo, 2)) + "' and " +;
			"year(adelinte.fec_adelan) = '" + ALLTRIM(right(ALLTRIM(lcPeriodo), 4) ) + "'"
	ENDIF
	
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "adelinte")
	
	SELECT adelinte
	GO TOP
	
	DO WHILE ! EOF() THEN
		lnIntPag = lnIntPag + adelinte.monto_adel
		SKIP 1
	ENDDO
	
	USE

	**	
	**	Restaura el alias.
	IF ! EMPTY(lcAlias) AND USED(lcAlias) THEN
		SELECT &lcAlias
	ENDIF

	RETURN lnIntPag

ENDFUNC

**	
**	Oscar E. Urdaneta
**	
**	Funcion: LunesDelMes()
**	Devuelve los lunes del mes correspondiente a la fecha nDesde (variable publica)
**	El parametro lcCodigoTrabajador se coloca solo por compatibilidad, no se utiliza en la funcion.
FUNCTION LUNESDELMES(lcCodigoTrabajador)

	LOCAL lnCount
	LOCAL ldFechaDesde, ldFechaHasta, ldDia

	lnCount = 0
	
	ldFechaDesde = CTOD("01/" + PADL(ALLTRIM(STR(MONTH(nDesde))), 2, "0") + "/" + STR(YEAR(nDesde)))
	ldFechaHasta = GOMONTH(ldFechaDesde, 1) - 1
	ldDia = ldFechaDesde

	DO WHILE ldDia <= ldFechaHasta
		IF DOW(ldDia) = 2 THEN
			lnCount = lnCount + 1
		ENDIF
		ldDia = ldDia + 1
	ENDDO
	
	RETURN lnCount
	
ENDFUNC

**	
**	Oscar E. Urdaneta
**	
**	Funcion: LunesDelPeriodo()
**	Devuelve el numero de lunes en el periodo que se va a procesar.
**	El parametro lcCodigoTrabajador se coloca solo por compatibilidad, no se utiliza en la funcion.
FUNCTION LUNESDELPERIODO(X)
	
	LOCAL lnCount
	LOCAL ldFechaDesde, ldFechaHasta, ldDia
	
	lnCount = 0
	
	ldFechaDesde = nDesde
	ldFechaHasta = nHasta
	ldDia = ldFechaDesde

	DO WHILE ldDia <= ldFechaHasta
		IF DOW(ldDia) = 2 THEN
			lnCount = lnCount + 1
		ENDIF
		ldDia = ldDia + 1
	ENDDO
	
	RETURN lnCount
	
ENDFUNC

**	
**	Jesus Lopez
**	
**	Funcion: SabadosDelPeriodo()
**	Devuelve el numero de Sabados en el periodo que se va a procesar.
**	El parametro lcCodigoTrabajador se coloca solo por compatibilidad, no se utiliza en la funcion.
FUNCTION SABADOSDELPERIODO(X)
	
	LOCAL lnCount
	LOCAL ldFechaDesde, ldFechaHasta, ldDia
	
	lnCount = 0
	
	ldFechaDesde = nDesde
	ldFechaHasta = nHasta
	ldDia = ldFechaDesde

	DO WHILE ldDia <= ldFechaHasta
		IF DOW(ldDia) = 7 THEN
			lnCount = lnCount + 1
		ENDIF
		ldDia = ldDia + 1
	ENDDO
	
	RETURN lnCount
	
ENDFUNC

**	
**	Jesus Lopez
**	
**	Funcion: DomingosDelPeriodo()
**	Devuelve el numero de Domingos en el periodo que se va a procesar.
**	El parametro lcCodigoTrabajador se coloca solo por compatibilidad, no se utiliza en la funcion.
FUNCTION DOMINGOSDELPERIODO(X)
	
	LOCAL lnCount
	LOCAL ldFechaDesde, ldFechaHasta, ldDia
	
	lnCount = 0
	
	ldFechaDesde = nDesde
	ldFechaHasta = nHasta
	ldDia = ldFechaDesde

	DO WHILE ldDia <= ldFechaHasta
		IF DOW(ldDia) = 1 THEN
			lnCount = lnCount + 1
		ENDIF
		ldDia = ldDia + 1
	ENDDO
	
	RETURN lnCount
	
ENDFUNC

**	
**	Oscar E. Urdaneta
**	Jesus Lopez
**	Funcion: UtilFrac()
FUNCTION UTILFRAC(f1,f2)
	
	**	
	**	Variables locales.
	LOCAL ldFechaInicio, ldFechaFinal
	LOCAL lnMeses, lnDiasUtilidades, lnTotalDias
	LOCAL lcSqlCommand

	**	
	**	Utiliza el cursor tmpTrabajad para tomar las fecha de inicio y fin.
	IF USED("tmpTrabajad") AND (EMPTY(f1) or EMPTY(f2)) THEN
		ldFechaInicio = tmpTrabajad.fecha_ini
		ldFechaFinal = tmpTrabajad.fecha_fin
	ELSE
		ldFechaInicio = f1
		ldFechaFinal  = f2
	ENDIF
	
	lnMeses = INT((ldFechaFinal - ldFechaInicio) / 30)
	lnDiasUtilidades = 0
	lnTotalDias = 0

	lcSqlCommand =;
		"select " +;
			"confpres.* " +;
		"from " +;
			"confpres " +;
		"where " +;
			"id_nomina = '" + xId_Nomina + "'"

	ExeSentencia(OdbcMasterConector, lcSqlCommand, "curConfPres")

	SELECT curConfPres
	GO BOTTOM   &&& ultima ley de la tabla
	
	lnDiasUtilidades = curConfPres.diasutil
	lnTotalDias = (lnMeses * lnDiasUtilidades) / 12

	RETURN lnTotalDias

ENDFUNC

**	
**	Oscar E. Urdaneta
**	
**	Calcula los montos pendientes de los prestamos personales.
FUNCTION PRESPEND(X)
	
	**	
	**	Variables locales.
	LOCAL lnSaldoPrestamo
	LOCAL lcSqlCommand
	
	lnSaldoPrestamo = 0

	lcSqlCommand = ""
	
	**	
	**	Carga la tabla de prestamos.
	lcSqlCommand = "select prestamo.* from prestamo where " + "id_nomina = '" + xId_Nomina + "'"
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "prestamo")

	SELECT SUM(saldo_pres) AS saldot FROM prestamo INTO CURSOR saldo WHERE cod_trab = nCod_Trab GROUP BY cod_trab

	SELECT saldo
	GO TOP

	lnSaldoPrestamo = saldo.saldot

	RETURN lnSaldoPrestamo

ENDFUNC

**	
**	Funcion: ASTR()
FUNCTION astr(num, numdecimales)
	IF PCOUNT() = 1 THEN
		RETURN ALLTRIM(STR(num, 22))
	ELSE
		RETURN ALLTRIM(STR(num , 22, numdecimales))
	ENDIF
ENDFUNC

**	
**	Oscar E. Urdaneta
**	
**	Funcion: DiasFeriados
**	Recibe como parametros un rango de fechas (inicial y final) y devuelve la cantidad de dias
**	feriados establecidos en la tabla calendario en ese periodo.
FUNCTION DIASFERIADOS(ldFechaInicio, ldFechaFin)

	**	
	**	Variables locales.
	LOCAL lnDiasFeriados
	LOCAL lcSqlCommand, lcFechaInicio, lcFechaFin
	
	lnDiasFeriados = 0
	
	lcSqlCommand = ""
	lcFechaInicio = ""
	lcFechaFin = ""
	
	
	**	
	**	Si existe el alias tmpTrabajad toma de ahi las fecha inicial y final.
	IF USED("tmpTrabajad") THEN
		ldFechaInicio = tmpTrabajad.fecha_ini
		ldFechaFin = tmpTrabajad.fecha_fin
	ENDIF

	lcFechaInicio = Date2MySql(ldFechaInicio)
	lcFechaFin = Date2MySql(ldFechaFin)

	**	
	**	Busca los dias feriados establecidos en la tabla calendario.
	lcSqlCommand =;
		"select " +;
			"calendario.* " +;
		"from " +;
			"calendario " +;
		"where " +;
			"calendario.id_nomina = '" + xId_Nomina + "' and " +;
			"calendario.fecha between '" + lcFechaInicio + "' and '" + lcFechaFin + "'"
	
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "curCalendario")
	
	SELECT curCalendario
	GO TOP
	lnDiasFeriados = RECCOUNT()
	USE

	**	
	**	Devuelve el numero de dias feriados.
	RETURN lnDiasFeriados

ENDFUNC

**	
**	Oscar E. Urdaneta
**	
**	Funcion: Constante.
**	Devuelve el valor de una constante asignada al trabajador
FUNCTION Constante(xConstante)

	**	
	**	Variables locales.
	LOCAL lcSqlCommand1, lcSqlCommand2
	
	lcSqlCommand1 =;
		"select " +;
			"consasig.* " +;
		"from " +;
			"consasig " +;
		"where " +;
			"consasig.cod_const = '" + xConstante + "' and " +;
			"consasig.cod_trab = '" + nCod_Trab + "' and " +;
			"consasig.id_nomina = '" + xId_Nomina + "'"

	lcSqlCommand2 =;
		"select " +;
			"constant.* " +;
		"from " +;
			"constant " +;
		"where " +;
			"constant.cod_const = '" + ALLTRIM(xConstante) + "' and " +;
			"constant.id_nomina = '" + xId_Nomina + "'"

	**	
	**	Carga las constantes asignadas al trabajador.
	ExeSentencia(OdbcMasterConector, lcSqlCommand1, "qConsAsig")

	SELECT qConsAsig
	GO TOP

	IF ! EOF() THEN
	
		cValor = Valor
		nCantidad = Valor
		xnUnidad = Unidad

		IF cValor = 0 THEN
		
			xCValor = 0
			
			ExeSentencia(OdbcMasterConector, lcSqlCommand2, "constant")

			SELECT constant
			GO TOP
			
			IF ! EOF() THEN
			
				cValor = Valor
				xnUnidad = Unidad
				xCValor = 1

				IF cValor = 0 THEN
					xCValor = 0
				ENDIF
			ENDIF
		ELSE
			xCValor = 1
		ENDIF

	ELSE
	
		ExeSentencia(OdbcMasterConector, lcSqlCommand2, "constant")

		SELECT constant
		GO TOP
		
		IF ! EOF() THEN
		
			cValor = Valor
			nCantidad = Valor
			xnUnidad = Unidad

			IF cValor = 0 THEN
				xCValor = 0
			ELSE
				xCValor = 1
			ENDIF

		ELSE
			cValor = 0
			xCValor = 0
			nCantidad = 0
			nUnidad = ""
		ENDIF
	ENDIF

	RETURN cValor

ENDFUNC

**	
**	Oscar E. Urdaneta
**	
**	Funcion: Conceptos.
**	Devuelve el valor de un concepto asignado a un trabajador.
FUNCTION Conceptos(xConcepto)

	**	
	**	Variables locales.
	LOCAL lcSqlCommand
	
	lcSqlCommand = ""
	
	**	
	**	Carga los conceptos.
	lcSqlCommand =;
		"select " +;
			"concepto.* " +;
		"from " +;
			"concepto " +;
		"where " +;
			"concepto.cod_concep = '" + ALLTRIM(xConcepto) + "' and " +;
			"concepto.id_nomina = '" + xid_nomina + "'"

	ExeSentencia(OdbcMasterConector, lcSqlCommand, "qconcepto")
	SELECT qconcepto
	GO TOP
	
	SET EXAC OFF

	cValor = 0

	IF ! EOF() THEN

		= ALINES(nXFormula, qconcepto.formula)

		nXResultado1 = ""
		nXResultado2 = ""

		xRecursividad(@nXFormula, @nXResultado1)
		nXResultado1 = CleanFormula(nXResultado1)
		nXResultado2 = EVALUATE(nXResultado1)
		cValor = nXResultado2
		RETURN cValor

	ENDIF

	RETURN cValor

ENDFUNC

**	
**	Oscar E. Urdaneta
**	
**	Funcion: CleanFormula
**	Elimina espacios en blanco y reemplaza las comas por puntos en los decimales.
FUNCTION CleanFormula(lcFormula)

	**	
	**	Variables locales.
	LOCAL lnI, lnLen
	LOCAL lcResult, lcChar
	
	lnI = 0
	lnLen = LEN(lcFormula)
	
	lcResult = ""
	lcChar = ""
	
	FOR lnI = 1 TO lnLen STEP 1
		lcChar = SUBSTR(lcFormula, lnI, 1)
		IF lcChar = CHR(32) THEN
			LOOP
		ENDIF
		IF lcChar = "," THEN
			lcChar = "."
		ENDIF
		lcResult = lcResult + lcChar
	ENDFOR

	RETURN lcResult

ENDFUNC

**	
**	Oscar E. Urdaneta
**	
**	Funcion: CalGaran
**	Calcula la 'Garantia de Prestaciones', concepto desconocido, se esta colocando la funcion
**	por compatibilidad, el concepto debe ser eliminado de la lista de conceptos disponibles.
FUNCTION CalGaran(lxP1, lxP2, lxP3, lxP4, lxP5, lxP6, lxP7, lxP8, lxP9, lxP10, lxP11, lxP12, lxP13,;
	lxP14, lxP15, lxP16, lxP17, lxP18, lxP19, lxP20, lxP21, lxP22, lxP23, lxP24, lxP25, lxP26)

	RETURN 0

ENDFUNC

**	
**	Oscar E. Urdaneta
**	
**	Funcion: MesAntig
**	Calcula los meses de antiguedad en caso de tener el trabajador menos de un ao de labor.
FUNCTION MESANTIG(X)

	**	
	**	Variables locales.
	LOCAL llFechaIngreso
	LOCAL lnTotaPres, lnMeses

	llFechaIngreso = .F.

	lnTotaPres = 0
	lnMeses = 0
	
	**	
	**	Establece el valor de gdFechaIngreso.
	IF VARTYPE(gdFechaIngreso) != "D" THEN
		IF USED("trabajad") AND ! EMPTY(trabajad.fecha_ing) THEN
			gdFechaIngreso = trabajad.fecha_ing
			llFechaIngreso = .T.
		ENDIF
	ELSE
		llFechaIngreso = .T.
	ENDIF

	**	
	**	Si no esta establecida la fecha de ingreso no puede realizar el calculo.
	IF llFechaIngreso THEN

		**	
		**	Calcula el tiempo de labor en la empresa.
		lnMeses = (fecha_fin - gdFechaIngreso) / 30

		IF lnMeses <= 12 THEN
			lnTotaPres = lnMeses
		ENDIF
		
	ELSE
		= MESSAGEBOX("No esta establecida la fecha de ingreso en la funcion MESANTIG, no es posible realizar el calculo", 64, Software)
	ENDIF

	RETURN lnTotaPres

ENDFUNC



**************************************************************************************
** NUEVAS FUNCIONES LIQUIDACIONES. JESUS LOPEZ										 *
**************************************************************************************
**	
**	Calcula las prestaciones acumuladas del trabajador desde las nuevas tablas histnomina
FUNCTION TOTAPRES(X)
*X: codigo del trabajador
*Prestaciones acumuladas
*Autor: CASA MATRIZ
*Fecha de creacin: 20080813
*Ultima actualizacin: 20160408. Jesus Lopez.
*------------------------------------------------------------------------------------
LOCAL lnPresAcum, lnAdelPres, lnTotaPres, lnSaldoPrest, lnAdelInte, lnMeses , lcSqlCommand

lnMeses 	 = 0.00
lnTotaPres   = 00000000.00
lnPresAcum   = 00000000.00	
lnSaldoPrest = 00000000.00

lcSqlCommand = ""
	
	**	
	**	Carga los trabajadores.
	lcSqlCommand =;
		"select " +;
			"trabajad.* " +;
		"from " +;
			"trabajad " +;
		"where " +;
			"id_nomina = '"+ xId_Nomina + "' AND cod_trab = '" + ALLTRIM(X) + "'"
			
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "trabajad")
	SELECT trabajad	
	GO TOP
	
	lnSaldoPrest = prestaciones_a
	
	**	Carga los historicos.
	lcSqlCommand =;
		"select " +;
			"histnomina_det.* " +;
		"from " +;
			"histnomina_det " +;
		"where " +;
			"id_nomina = '"+ xId_Nomina + "' AND cod_trab = '" + ALLTRIM(X) + "'"
			
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "qhist_det")
	
	select * from qhist_det into cursor qhist_det order by id_nomina,cod_trab,right(rtrim(num_peri),4), left(num_peri,2)
	select qhist_det
	go bott
	
    lnPresAcum = acuprest
			
		
	lnTotaPres = lnPresAcum
	
	
RETURN lnTotaPres
ENDFUNC


**	Calcula los intereses de prestaciones pendientes del trabajador desde las nuevas tablas intepres
FUNCTION INTERESES(X)
*X: codigo del trabajador
*Intereses acumulados por pagar
*Autor: CASA MATRIZ
*Fecha de creacin: 20160408
*Ultima actualizacin: 20160408. Jesus Lopez.
*------------------------------------------------------------------------------------
LOCAL lnTotaInte , lnMeses , lcSqlCommand

lnMeses 	 = 0.00
lnTotaInte   = 00000000.00
lcSqlCommand = ""
	
	**	
	**	Carga los trabajadores.
	lcSqlCommand =;
		"select " +;
			"trabajad.* " +;
		"from " +;
			"trabajad " +;
		"where " +;
			"id_nomina = '"+ xId_Nomina + "' AND cod_trab = '" + ALLTRIM(X) + "'"
			
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "trabajad")
	SELECT trabajad	
	GO TOP
	
	**	Carga los historicos.
	lcSqlCommand =;
		"select " +;
			"intepres.* " +;
		"from " +;
			"intepres " +;
		"where " +;
			"id_nomina = '"+ xId_Nomina + "' AND cod_trab = '" + ALLTRIM(X) + "' and estatus='0'"
			
	ExeSentencia(OdbcMasterConector, lcSqlCommand, "qhist_det")
	
	select SUM(montinte) as totinte from qhist_det WHERE estatus=0 into cursor qhist_det group by id_nomina,cod_trab
	select qhist_det
	go top
	
    lnTotaInte = qhist_det.totinte 
			
RETURN lnTotaInte
ENDFUNC
*************************************************************************************

FUNCTION BUSCA_DIASUTIL(dFechaAct)
*
*DIAS DE UTILIDAD
*Autor: Jesus Lopez.
*Fecha de creacin: 26/05/2015
*
*------------------------------------------------------------------------------------

** JL. 26/05/2015


		
		** Extrayendo y aplicando Dias de Utilidades por Ano
		**	
		**	Variables locales.
		LOCAL lcSqlCommand,lnDiasUtil 

		lcSqlCommand = ''

		**	
		**	Establece la sentencia SQL.
		lcSqlCommand =;
			"select * " +;
				"from " +;
				"conf_diasutil " +;
				"where " +;
				"id_nomina = '" + xid_nomina + "' and " +;
				"fecha <= '" + date2mysql(dFechaAct) +"' order by " +;
				"fecha desc limit 1"
		
		a = ExeSentencia(OdbcMasterConector, lcSqlCommand, "tmpConf_diasutil")

		**************************************************

		SELECT tmpConf_diasutil
		GOTO TOP
		IF EOF()
			
			**	Establece la sentencia SQL.
			lcSqlCommand =;
				"select * " +;
					"from " +;
					"conf_diasutil " +;
					"where " +;
					"id_nomina = '" + xid_nomina + "' and " +;
					"fecha >= '" + date2mysql(dFechaAct) +"' order by " +;
					"fecha asc limit 1"

			ExeSentencia(OdbcMasterConector, lcSqlCommand, "tmpConf_diasutil")

			IF !EOF()
				lnDiasUtil = tmpConf_diasutil.diasutil	
			ELSE
				lnDiasUtil = tmpConfPres.diasutil
			ENDIF
			
		ELSE
			
			lnDiasUtil = tmpConf_diasutil.diasutil	
		
		ENDIF
		*********************************************************
						
RETURN lnDiasUtil 
ENDFUNC
						
*********************************************************************************


*************************************************************************************
FUNCTION ASIG_TOTAL(nCod_trab,fDesde,fHasta)
*Cdigo del trabajador
*Suma de asignaciones por pago de nomina para un periodo determinado
*Autor: Jesus Lopez
*Fecha de creacin: 20150820
*------------------------------------------------------------------------------------
LOCAL lnAsignacionesNomina

	lnAsignacionesNomina = 0.00
	
		if PCOUNT() = 3 
			ldFechaDesde = fdesde
			ldFechaHasta = fhasta
		ELSE
			MESSAGEBOX("Faltan Datos en la Funcion")
			RETURN 0
		ENDIF

*!*		lcWhere = "id_nomina = '" + xid_nomina + "' and " + ;
*!*		          "cod_trab = '" + ncod_trab + "' and " + ;
*!*		          "desde >= '" + date2mysql(ldfechadesde) + "' and "+;
*!*		          "hasta <= '" + date2mysql(ldfechahasta) + "' and tipo_con = '1' "
	
	lcWhere = [id_nomina = "] + xid_nomina + [" and ] + ;
	          [cod_trab = "] + ncod_trab + [" and ] + ;
	          [desde >= "] + date2mysql(ldfechadesde) + [" and ]+;
	          [hasta <= "] + date2mysql(ldfechahasta) + [" and tipo_con = "1" ]
	          
	CargarDatosEnCursor(OdbcMasterConector, "*", "nominas2", lcWhere, "", "nominas2")
	SELECT nominas2
	GO TOP
	SUM valor TO lnAsignacionesNomina
	RETURN lnAsignacionesNomina
ENDFUNC
*************************************************************************************

FUNCTION ASIG_TOTAL_VACA(nCod_trab,fDesde,fHasta)
*Cdigo del trabajador
*Suma de asignaciones por pago de nomina para un periodo determinado que Afectan VACACIONES
*Autor: Jesus Lopez
*Fecha de creacin: 20150820
*------------------------------------------------------------------------------------
LOCAL lnAsignacionesNomina

	lnAsignacionesNomina = 0.00
	
		if PCOUNT() = 3 
			ldFechaDesde = fdesde
			ldFechaHasta = fhasta
		ELSE
			MESSAGEBOX("Faltan Datos en la Funcion")
			RETURN 0
		ENDIF

	lcWhere = [id_nomina = "] + xid_nomina + [" and ] + ;
	          [cod_trab = "] + ncod_trab + [" and ] + ;
	          [desde >= "] + date2mysql(ldfechadesde) + [" and ]+;
	          [hasta <= "] + date2mysql(ldfechahasta) + [" and tipo_con = "1"]
	
	lcWhere2 = [id_nomina = "] + xid_nomina + [" and cal_vac = "1"]
	        
	CargarDatosEnCursor(OdbcMasterConector, "*", "nominas2", lcWhere, "", "tnominas2")
	CargarDatosEnCursor(OdbcMasterConector, "*", "concepto", lcWhere2, "", "qConc")
	
	SELECT tnominas2.valor FROM tnominas2 INNER JOIN qConc ON tnominas2.cod_concep=qConc.cod_concep;
	INTO CURSOR tnominas2
	
	SELECT tnominas2
	GO TOP
	SUM valor TO lnAsignacionesNomina
	RETURN lnAsignacionesNomina
ENDFUNC
*************************************************************************************
*************************************************************************************
FUNCTION ASIG_TOTAL_UTIL(nCod_trab,fDesde,fHasta)
*Cdigo del trabajador
*Suma de asignaciones por pago de nomina para un periodo determinado que Afectan VACACIONES
*Autor: Jesus Lopez
*Fecha de creacin: 20150820
*------------------------------------------------------------------------------------
LOCAL lnAsignacionesNomina

	lnAsignacionesNomina = 0.00
	
		if PCOUNT() = 3 
			ldFechaDesde = fdesde
			ldFechaHasta = fhasta
		ELSE
			MESSAGEBOX("Faltan Datos en la Funcion")
			RETURN 0
		ENDIF

	lcWhere = [id_nomina = "] + xid_nomina + [" and ] + ;
	          [cod_trab = "] + ncod_trab + [" and ] + ;
	          [desde >= "] + date2mysql(ldfechadesde) + [" and ]+;
	          [hasta <= "] + date2mysql(ldfechahasta) + [" and tipo_con = "1"]
	
	lcWhere2 = [id_nomina = "] + xid_nomina + [" and cal_uti = "1"]
	        
	CargarDatosEnCursor(OdbcMasterConector, "*", "nominas2", lcWhere, "", "tnominas2")
	CargarDatosEnCursor(OdbcMasterConector, "*", "concepto", lcWhere2, "", "qConc")
	
	SELECT tnominas2.valor FROM tnominas2 INNER JOIN qConc ON tnominas2.cod_concep=qConc.cod_concep;
	INTO CURSOR tnominas2
	
	SELECT tnominas2
	GO TOP
	SUM valor TO lnAsignacionesNomina
	RETURN lnAsignacionesNomina
ENDFUNC

*****************************************************************************************
FUNCTION SUELDOBASE (xCodTrab)
*!* Determina el sueldo basico de un trabajador UTILIZANDO LA NUEVA VARIABLE 'salariobasico' de la tabla constant
*!* en caso de no estar marcada, toma la constante 'SUEL'
*!* Autor: CASA MATRIZ / JL
*!* Fecha de creacin: 2015-11-05
*!* Ultima actualizacin:
**Buscando sueldo basico

	sentencia = "c2.salariobasico = 1 AND c1.cod_trab = '"+xCodTrab+"' and c1.id_nomina = '" + xId_Nomina + "'"
	tablas = "consasig c1 inner join constant c2 on c1.id_nomina = c2.id_nomina and c1.cod_const = c2.cod_const"
	CargarDatosEnCursor(OdbcMasterConector, "c1.*", tablas, sentencia, "", "tmpConsasig")
				
	SELECT tmpConsasig
	GO TOP
	
	IF !EOF() THEN
		cSueldoMensual		= tmpConsasig.valor
	ELSE
		lcWhere	=;
		"Id_Nomina = '" + xid_nomina + "' and "	+;
		"cod_trab = '" + xCodTrab + "' and " +;
		"cod_const = 'SUEL'"
		CargarDatosEnCursor(OdbcMasterConector, "*", "consasig", lcWhere, "", "tmpConsasig")
		cSueldoMensual		= tmpConsasig.valor
	ENDIF

RETURN cSueldoMensual

ENDFUNC

************************************************
FUNCTION SUELDOPROM ( cCod_Trab, dFechaHasta, nMeses)
*!* Determina el sueldo promedio por rango de meses de un trabajador
*!* Autor: CASA MATRIZ / JL
*!* Fecha de creacin: 2015-11-08
*!* Ultima actualizacin:
LOCAL sueldobase
sueldobase = SUELDOBASE(cCod_Trab)
*ASIG_TOTAL(nCod_trab,fDesde,fHasta)
LOCAL lnSalario,lcFechaFin,lcFechaIni,fechaRef
							
lcFechaFin 			= dFechaHasta				&& mes anterior

fechaRef 	= GOMONTH(lcFechaFin,-1*nMeses)

lcFechaini 	= DATE( YEAR(fechaRef), MONTH(fechaRef), 1)
		
lnSalario 	= ASIG_TOTAL(cCod_Trab,lcFechaini,lcFechaFin) / nMeses

IF lnSalario <= sueldobase 
	lnSalario = sueldobase 
endif

RETURN lnSalario 

ENDFUNC


**************************************************************

FUNCTION ASIGLIQ(nCod_trab)
*codigo de trabajador
*Clculo de asignaciones desde el cursor de liquidacin.
*Autor: JESUS LOPEZ
*Fecha de creacin: 20151015
*Ultima actualizacin: 20164007
*------------------------------------------------------------------------------------
LOCAL lnTotalAsignaciones

lnTotalAsignaciones = 0.00

SELECT SUM(asignacion) as valor FROM tmpConceptosLiq where cod_trab = nCod_trab INTO CURSOR qAsigna
GO TOP

lnTotalAsignaciones  = qAsigna.valor

borra_cursor("qAsigna")

RETURN lnTotalAsignaciones

ENDFUNC
*************************************************************************************

***************************************************************
FUNCTION ASIGFAOV(xCod_concep)
*****************************************************************************************************************************************************
** Este mtodo se cre debido a que la funcion ASIGLPH est diseada para obtener los datos directamente de la tabla nominas2. Por tal razn,
** al momento de calcular la prnomina por vez primera en cualquier periodo los conceptos que contenian dicha funcin no se reflejaban en la ventana
** hasta tanto no se actualizaran los valores de la prenmina. Este mtodo realiza los mismos clculos de la funcin ASIGLPH pero no basado en la
** tabla nominas2.(Jesus Lopez 04/04/2016)
*****************************************************************************************************************************************************

codconcep=xCod_concep			&&Concepto que contiene la funcion ASIGFAOV

ncod_trab=ALLTRIM(ncod_trab)

xtotal = 0

** Creo un cursor con los conceptos asignados al trabajador que sean tipo asignacin y que apliquen para el clculo de la nmina.
sentencia10="select concepto.cod_concep,concasig.cod_trab,concasig.tipo from concasig inner join concepto on concepto.id_nomina=concasig.id_nomina "
sentencia20="and concasig.cod_concep=concepto.cod_concep inner join numper_concep on concasig.cod_concep=numper_concep.cod_concep where "
lcWhere = "concepto.id_nomina='"+xId_Nomina+"' and concepto.va_nomina=1 and concepto.va_faov=1 and concasig.cod_trab='"+ncod_trab+"'"
lcWhere = lcWhere +" and concasig.activo=1 and concasig.tipo=1 and numper_concep.desde='"+date2mysql(ndesde)+"' group by concasig.cod_concep"
ExeSentencia(OdbcMasterConector,sentencia10+" "+sentencia20+" "+lcWhere ,"qcursor")
SELECT * FROM qcursor ORDER BY cod_trab,tipo,cod_concep INTO CURSOR qcursor 
SELECT tem_nom
SET ORDER TO ctipo
SELECT SUM(tem_nom.asignacion) as valor FROM tem_nom INNER JOIN qcursor ON tem_nom.cod_concep = qcursor.cod_concep AND tem_nom.cod_trab = qcursor.cod_trab ;
GROUP BY tem_nom.cod_trab INTO CURSOR qValor

xtotal = qValor.valor

SELECT tem_nom
SET ORDER TO cod_trab
**********************************************************************************************************************************************
** El siguiente bloque permite buscar en la frmula del concepto donde se encuentra la funcin ASIGFAOV asi como sus respectivos parmetros	**
** y reemplazarlos por el resultado calculado en el bloque anterior. (Jesus Lopez. 04/04/2016)													**
**********************************************************************************************************************************************

sentencia5 = "id_nomina ='"+xId_Nomina+"' and cod_concep = '"+codconcep+"'"
CargarDatosEnCursor(OdbcMasterConector, "*", "concepto", sentencia5, "", "qFaov")
GO TOP

ALINES(xform,qFaov.formula)

	** Armo la cadena resultante desde donde comienza ASIGFAOV hasta donde termina
	subcad = "ASIGFAOV()"
	
	** Sustituyo el valor calculado en el bloque anterior donde exista la funcion ASIGFAOV 
	xform = STRTRAN(xform,subcad,ALLTRIM(numerostring(xTotal, 2)))	
	xResultado=''
	
	** Proceso la formula
	IF Procesa_Formula(@xform, @xResultado)
			IF xCvalor = 0
				xValor = 0
			ELSE
				xValor = &xResultado
			ENDIF
	ENDIF
	
	return xValor   && Valor final

ENDFUNC
*************************************************************************************

FUNCTION ASIGDIADES(xCod_concep)
*****************************************************************************************************************************************************
** Este mtodo se cre para poder determinar el valor del dia derscanso sin tener que leer de la tabla nominas2. 
**(Jesus Lopez 04/04/2016)
*****************************************************************************************************************************************************

codconcep=xCod_concep			&&Concepto que contiene la funcion ASIGDIADES

ncod_trab=ALLTRIM(ncod_trab)

xtotal = 0

** Creo un cursor con los conceptos asignados al trabajador que sean tipo asignacin y que apliquen para el clculo de la nmina.
sentencia10="select concepto.cod_concep,concasig.cod_trab,concasig.tipo from concasig inner join concepto on concepto.id_nomina=concasig.id_nomina "
sentencia20=" and concasig.cod_concep=concepto.cod_concep inner join numper_concep on concasig.cod_concep=numper_concep.cod_concep where "
lcWhere = "concepto.id_nomina='"+xId_Nomina+"' and concepto.va_nomina=1 and concepto.va_diades=1 and concasig.cod_trab='"+ncod_trab+"'"
lcWhere = lcWhere +" and concasig.activo=1 and concasig.tipo=1 and numper_concep.desde='"+date2mysql(ndesde)+"' group by concasig.tipo,concasig.cod_concep"
ExeSentencia(OdbcMasterConector,sentencia10+" "+sentencia20+" "+lcWhere ,"qcursor")
SELECT * FROM qcursor ORDER BY cod_trab,tipo,cod_concep INTO CURSOR qcursor 
SELECT tem_nom
SET ORDER TO ctipo
SELECT SUM(tem_nom.asignacion) as valor FROM tem_nom INNER JOIN qcursor ON tem_nom.cod_concep = qcursor.cod_concep AND tem_nom.cod_trab = qcursor.cod_trab ;
GROUP BY tem_nom.cod_trab INTO CURSOR qValor

xtotal = qValor.valor

SELECT tem_nom
SET ORDER TO cod_trab
**********************************************************************************************************************************************
** El siguiente bloque permite buscar en la frmula del concepto donde se encuentra la funcin ASIGFAOV asi como sus respectivos parmetros	**
** y reemplazarlos por el resultado calculado en el bloque anterior. (Jesus Lopez. 04/04/2016)													**
**********************************************************************************************************************************************

sentencia5 = "id_nomina ='"+xId_Nomina+"' and cod_concep = '"+codconcep+"'"
CargarDatosEnCursor(OdbcMasterConector, "*", "concepto", sentencia5, "", "qdiades")
GO TOP

ALINES(xform,qdiades.formula)

	** Armo la cadena resultante desde donde comienza ASIGFAOV hasta donde termina
	subcad = "ASIGDIADES()"
	
	** Sustituyo el valor calculado en el bloque anterior donde exista la funcion ASIGFAOV 
	xform = STRTRAN(xform,subcad,ALLTRIM(numerostring(xTotal, 2)))	
	xResultado=''
	
	** Proceso la formula
	IF Procesa_Formula(@xform, @xResultado)
			IF xCvalor = 0
				xValor = 0
			ELSE
				xValor = &xResultado
			ENDIF
	ENDIF
	
	return xValor   && Valor final
ENDFUNC
*************************************************************************************


************************************
FUNCTION UTILFRAC_LIQ(X)
**	Jesus Lopez
**	Funcion: UtilFrac_liq()
**  Se usa para calcular la franccion de utilidad en la liquidacion de prestaciones
**  13/04/2016
	
	**	
	**	Variables locales.
	LOCAL ldFechaInicio, ldFechaFinal
	LOCAL lnMeses, lnDiasUtilidades, lnTotalDias
	LOCAL lcSqlCommand

	**	
	**	Utiliza el cursor tmpTrabajad para tomar las fecha de inicio y fin.
	IF USED("tmpTrabajad") THEN
		ldFechaInicio = DATE(YEAR(tmpTrabajad.fecha_fin),1,1)  
		ldFechaFinal  = tmpTrabajad.fecha_fin
	ELSE
		= MESSAGEBOX("No se encuentra el cursor 'tmpTrabajad', no se cuenta con la fecha de inicio y fin", 64, Software)
		RETURN 0
	ENDIF
	
	lnMeses = INT((ldFechaFinal - ldFechaInicio) / 30)
	lnDiasUtilidades = 0
	lnTotalDias = 0

	lcSqlCommand =;
		"select " +;
			"confpres.* " +;
		"from " +;
			"confpres " +;
		"where " +;
			"id_nomina = '" + xId_Nomina + "'"

	ExeSentencia(OdbcMasterConector, lcSqlCommand, "curConfPres")

	SELECT curConfPres
	GO BOTTOM   &&& ultima ley de la tabla
	
	lnDiasUtilidades = curConfPres.diasutil
	lnTotalDias = (lnMeses * lnDiasUtilidades) / 12

	RETURN lnTotalDias

ENDFUNC

************************************
FUNCTION VACAFRAC_LIQ(xCod_Trab)
*!* Determina el monto de Vacaciones Proporcionales desde la ultina Vacacion tomada
*!* hasta la fecha de salida
*!* Ultima actualizacin: **  13/04/2016
*!* ING. JESUS LOPEZ
*** REPROGRAMADA Y PUESTA EN USO PARA CALCULO DE LIQUIDACIONES. JL.

LOCAL xCodVac, xFechaFin, nValor
*

xCodVac		= '0001'
xFechaFin	= tmpTrabajad.fecha_fin
nDiasAnt	= (tmpTrabajad.fecha_fin - tmpTrabajad.fecha_ing)
nValor		= 0.00
*
		lcWhere = [id_nomina = "] + xId_nomina + [" and cod_trab = "] + xCod_Trab + [" and ] +;
				  [codliquidacion = "]	+ xCodVac + [" and procesado = "1"]
		cargardatosencursor( odbcmasterconector, "*", "liqencabezado", lcWhere , "fecha_proceso", "xliqencab" )
		GO bott
		IF !EOF( "xliqencab" )
			fecha1 = xliqencab.fecha_fin + 1
			fecha2 = xFechaFin
		ELSE
			fecha1 = tmpTrabajad.fecha_ing
			fecha2 = xFechaFin	
		ENDIF
*
	borra_cursor( "xliqencab" )
	
	lnMeses = INT((fecha2 - fecha1 ) / 30)  && meses laborados. pendientes de pago.
	
	nValor = F_DIASVACA()*lnMeses / 12  && formula segun articulo 196 LOTTT
		
	RETURN nValor 

ENDFUNC
*!*---------------------------------------------------------------------------------------------------------------------*!*

************************************
FUNCTION F_DIASVACA(P1)
**	Jesus Lopez
**	Funcion: Determinar los Dias de Vacaciones  segun configuracion. Liquidacion de vacaciones.
** Articulo 190 LOTTT
**  13/04/2016
	
	**	
	**	Variables locales.
	LOCAL lcSqlCommand,lnTotalDias

	**	
	lnTotalDias = 0

	lcSqlCommand =;
		"select " +;
			"conf_vacaciones.* " +;
		"from " +;
			"conf_vacaciones " +;
		"where " +;
			"id_nomina = '" + xId_Nomina + "'"

	ExeSentencia(OdbcMasterConector, lcSqlCommand, "f_confvac")

	SELECT f_confvac
	GO bott &&& ultima ley de la tabla
	
	lnTotalDias = f_confvac.dias_ano
	
	borra_cursor( "f_confvac" )
	
	RETURN lnTotalDias

ENDFUNC

************************************
FUNCTION F_DIASBONO(P1)
**	Jesus Lopez
**	Funcion: Determinar los Dias de bono Vacacional  segun configuracion. Liquidacion de vacaciones.
** Articulo 192 LOTTT
**  13/04/2016
	
	**	
	**	Variables locales.
	LOCAL lcSqlCommand,lnTotalDias

	**	
	lnTotalDias = 0

	lcSqlCommand =;
		"select " +;
			"conf_vacaciones.* " +;
		"from " +;
			"conf_vacaciones " +;
		"where " +;
			"id_nomina = '" + xId_Nomina + "'"

	ExeSentencia(OdbcMasterConector, lcSqlCommand, "f_confvac")

	SELECT f_confvac
	GO bott 	&&& ultima ley de la tabla
	
	lnTotalDias = f_confvac.dias_bono
	
	RETURN lnTotalDias

ENDFUNC

************************************
FUNCTION F_DIASMAS(P1)
**	Jesus Lopez
**	Funcion: Determinar los Dias adicionales de bono Vacacional  segun configuracion. Liquidacion de vacaciones.
** Articulo 192 LOTTT
**  13/04/2016
	
	**	
	**	Variables locales.
	LOCAL lcSqlCommand,lnTotalDias

	**	
	lnTotalDias = 0

	lcSqlCommand =;
		"select " +;
			"conf_vacaciones.* " +;
		"from " +;
			"conf_vacaciones " +;
		"where " +;
			"id_nomina = '" + xId_Nomina + "'"

	ExeSentencia(OdbcMasterConector, lcSqlCommand, "f_confvac")

	SELECT f_confvac
	GO bott 	&&& ultima ley de la tabla
	
	lnTotalDias = f_confvac.dias_mas
	
	RETURN lnTotalDias

ENDFUNC

************************************
FUNCTION DIAS_UTIL(X)
**	Jesus Lopez
**	Funcion: Determinar los Dias DE UTILIDAD  segun configuracion. Pago de utilidades y liquidaciones
** Articulo 192 LOTTT
**  13/04/2016
	
	**	
	**	Variables locales.
	LOCAL lcSqlCommand,lnTotalDias

	**	
	lnTotalDias = 0

	lcSqlCommand =;
		"select " +;
			"confpres.* " +;
		"from " +;
			"confpres " +;
		"where " +;
			"id_nomina = '" + xId_Nomina + "'"

	ExeSentencia(OdbcMasterConector, lcSqlCommand, "f_confpres")

	SELECT f_confpres
	GO bott 	&&& ultima ley de la tabla
	
	lnTotalDias = f_confpres.diasutil
	
	RETURN lnTotalDias

ENDFUNC



*!*	************************************
*!*	FUNCTION DIASVACA(xCodTrab)
*!*	**	Jesus Lopez
*!*	**	Funcion: UtilFrac_liq()
*!*	**  13/04/2016
*!*		
*!*		**	
*!*		**	Variables locales.
*!*		LOCAL ldFechaInicio, ldFechaFinal
*!*		LOCAL lnMeses,lnAnos, lnDiasUtilidades, lnTotalDias
*!*		LOCAL lcSqlCommand

*!*		**	
*!*		**	Utiliza el cursor tmpTrabajad para tomar las fecha de inicio y fin.
*!*		IF USED("tmpTrabajad") THEN
*!*			ldFechaInicio = DATE(YEAR(tmpTrabajad.fecha_fin),1,1)  
*!*			ldFechaFinal = tmpTrabajad.fecha_fin
*!*		ELSE
*!*			= MESSAGEBOX("No se encuentra el cursor 'tmpTrabajad', no se cuenta con la fecha de inicio y fin", 64, Software)
*!*			RETURN 0
*!*		ENDIF
*!*		
*!*		**	
*!*		**	Determina la antiguedad del trabajador.
*!*		cAntiguedad	= calcula_antiguedad(tmpTrabajad.fecha_ing, tmpTrabajad.fecha_fin, .T.)
*!*		*aAntiguedad[1]	= VAL(SUBSTR(cAntiguedad,1,2))		&& Aos
*!*		*aAntiguedad[2]	= VAL(SUBSTR(cAntiguedad,4,2))		&& Meses
*!*		*aAntiguedad[3]	= VAL(SUBSTR(cAntiguedad,7))		&& Das

*!*			
*!*		lnAnos = VAL(LEFT(cAntiguedad,2))
*!*		
*!*		lnMeses = INT((ldFechaFinal - ldFechaInicio) / 30)
*!*		lnDiasUtilidades = 0
*!*		lnTotalDias = 0

*!*		lcSqlCommand =;
*!*			"select " +;
*!*				"confpres.* " +;
*!*			"from " +;
*!*				"confpres " +;
*!*			"where " +;
*!*				"id_nomina = '" + xId_Nomina + "'"

*!*		ExeSentencia(OdbcMasterConector, lcSqlCommand, "curConfPres")

*!*		SELECT curConfPres
*!*		GO bott &&& ultima ley de la tabla
*!*		
*!*		lnDiasUtilidades = curConfPres.diasutil
*!*		lnTotalDias = (lnMeses * lnDiasUtilidades) / 12

*!*		RETURN lnTotalDias

*!*	ENDFUNC
